
import type { Section }  from './types/PSC';

export const data: Section[] = [
  {
    title: 'Authentication',
    slug: 'authentication',
    description: 'Securing your online account login credentials',
    icon: 'password',
    intro: 'Most reported data breaches are caused by the use of weak, default or stolen passwords (according to [this Verizon report](http://www.verizonenterprise.com/resources/reports/rp_dbir-2016-executive-summary_xg_en.pdf)).' +
      'Use long, strong and unique passwords, manage them in a secure password manager, enable 2-factor authentication, keep on top of breaches and take care while logging into your accounts.',
    checklist: [
      {
        point: 'Use a Strong Password',
        priority: 'recommended',
        details: `If your password is too short, or contains dictionary words, places or names- then it can be easily cracked through brute force, or guessed by someone. The easiest way to make a strong password, is by making it long (12+ characters)- consider using a 'passphrase', made up of many words. Alternatively, use a password generator to create a long, strong random password. Have a play with [HowSecureIsMyPassword.net](https://howsecureismypassword.net), to get an idea of how quickly common passwords can be cracked. Read more about creating strong passwords: [securityinabox.org](https://securityinabox.org/en/passwords/passwords-and-2fa/)`,
      },
      {
        point: 'Don\'t reuse Passwords',
        priority: 'optional',
        details: `If someone was to reuse a password, and one site they had an account with suffered a leak, then a criminal could easily gain unauthorized access to their other accounts. This is usually done through large-scale automated login requests, and it is called Credential Stuffing. Unfortunately this is all too common, but it's simple to protect against- use a different password for each of your online accounts`,
      },
      {
        point: 'Use a Secure Password Manager',
        priority: 'advanced',
        details: `For most people it is going to be near-impossible to remember hundreds of strong and unique passwords. A password manager is an application that generates, stores and auto-fills your login credentials for you. All your passwords will be encrypted against 1 master passwords (which you must remember, and it should be very strong). Most password managers have browser extensions and mobile apps, so whatever device you are on, your passwords can be auto-filled. A good all-rounder is [BitWarden](https://bitwarden.com), or see [Recommended Password Managers](https://github.com/Lissy93/awesome-privacy#password-managers)`,
      },
    ],
    color: 'yellow',
  },
  {
    title: 'Web Browsing',
    slug: 'web-browsing',
    description: 'Avoiding tracking, censorship, and data collection online',
    icon: 'browser',
    intro: '',
    checklist: [],
    color: 'emerald',
  },
  {
    title: 'Email',
    slug: 'email',
    description: 'Protecting the gateway to your online accounts',
    icon: 'email',
    intro: '',
    checklist: [],
    color: 'teal',
  },
  {
    title: 'Messaging',
    slug: 'messaging',
    description: 'Keeping your communications private and secure',
    icon: 'messaging',
    intro: '',
    checklist: [],
    color: 'cyan',
  },
  {
    title: 'Social Media',
    slug: 'social-media',
    description: 'Minimizing the risks associated with using online communities',
    icon: 'social',
    intro: '',
    checklist: [],
    color: 'blue',
  },
  {
    title: 'Networks',
    slug: 'networks',
    description: 'Safeguarding your network traffic',
    icon: 'network',
    intro: '',
    checklist: [],
    color: 'violet',
  },
  {
    title: 'Mobile Devices',
    slug: 'mobile-devices',
    description: 'Reduce invasive tracking for cells, smartphones and tablets',
    icon: 'mobile',
    intro: '',
    checklist: [],
    color: 'fuchsia',
  },
  {
    title: 'Personal Computers',
    slug: 'personal-computers',
    description: 'Securing your PC\'s operating system, data & activity',
    icon: 'computer',
    intro: '',
    checklist: [],
    color: 'pink',
  },
  {
    title: 'Smart Home',
    slug: 'smart-home',
    description: 'Using IoT devices without compromising your privacy',
    icon: 'home',
    intro: '',
    checklist: [],
    color: 'red',
  },
  {
    title: 'Personal Finance',
    slug: 'personal-finance',
    description: 'Protecting your funds, financial accounts and transactions',
    icon: 'finance',
    intro: '',
    checklist: [],
    color: 'purple',
  },
  {
    title: 'Human Aspect',
    slug: 'human-aspect',
    description: 'Avoiding social engineering security risks',
    icon: 'human',
    intro: '',
    checklist: [],
    color: 'indigo',
  },
  {
    title: 'Physical Security',
    slug: 'physical-security',
    description: 'Taking measures to prevent IRL security incidents',
    icon: 'physical',
    intro: '',
    checklist: [],
    color: 'lime',
  },
];
